@@ -1,8 +1,10 @@
 """Errors"""
 
+
 class DependencyError(ImportError):
     """Specific dependency is missing"""
 
+
 class SecurityError(Exception):
     """SQLInjection ahead."""
 
@@ -22,5 +24,9 @@ class DatabaseExistsError(UnexpectedResultError):
 class DatabaseMissingError(UnexpectedResultError):
     """Database that would be accessed is missing."""
 
+
 class ObjectRemovedError(BaseException):
     """Object is deleted from memory and cannot be obtained"""
+
+class CuteDemonLordException(Exception):
+    """A demon lord (cute one, somehow a dude) aborts an SQL statement"""
